==> ember-cli-deploy-sh-0.2.1.tgz: package/lib/shell-tasks.js <==
'use strict';

var Promise = require('ember-cli/lib/ext/promise');
var shell   = require('../utils/shell');

module.exports = {
  executeTasks: executeTasks,

  executeTask: executeTask,

  validateTask: validateTask
};

/**
  @method executeTasks
  @param {String} name The hook name
  @param {Array} tasks An array of tasks
  @return {Promise}
**/
function executeTasks(name, tasks) {
  var promiseChain = Promise.resolve();
  var output = {
    log: this.log.bind(this),
    ui: this.ui
  };

  tasks.forEach(function(task, idx) {
    promiseChain = promiseChain.then(executeTask(name, task, output, idx));
  });

  return promiseChain;
}

/**

  @method executeTask
  @param {String} name The hook name.
  @param {Object} task The task.
  @param {Object} output { log, ui } for logging.
  @return {Promise}
*/
function executeTask(name, task, output, idx) {
  return function() {
    var validatedTask = validateTask(task);

    if (!validatedTask) {
      return Promise.reject(name + ': invalid tasks[' + idx + '].');
    }

    output.log(name + ': executing shell task');
    var command = shell.buildCommand(validatedTask);

    return shell.runCommand(command, output.ui);
  }
}

/**
  Performs basic validation on a task:
  1. `command` property exists and is a string.
  2. `options` property is an object.

  @method validateTasks
  @param {Object} task
**/
function validateTask(task) {
  if (typeof task.command !== 'string') {
    return;
  }

  if (task.options === null) {
    return;
  }

  if (task.options && typeof task.options !== 'object') {
    return;
  }

  return task;
}

==> ember-cli-deploy-sh-0.2.4.tgz: package/lib/shell-tasks.js <==
'use strict';

var Promise = require('ember-cli/lib/ext/promise');
var shell   = require('../utils/shell');

module.exports = {
  executeTasks: executeTasks,

  executeTask: executeTask,

  validateTask: validateTask
};

/**
  @method executeTasks
  @param {String} name The hook name
  @param {Array} tasks An array of tasks
  @return {Promise}
**/
function executeTasks(name, tasks) {
  var promiseChain = Promise.resolve();
  var log = this.log.bind(this);

  tasks.forEach(function(task, idx) {
    promiseChain = promiseChain.then(executeTask(name, task, log, idx));
  });

  return promiseChain;
}

/**

  @method executeTask
  @param {String} name The hook name.
  @param {Object} task The task.
  @param {Function} log
  @return {Promise}
*/
function executeTask(name, task, log, idx) {
  return function() {
    var validatedTask = validateTask(task);

    if (!validatedTask) {
      return Promise.reject(name + ': invalid tasks[' + idx + '].');
    }

    log(name + ': executing shell task');
    var command = shell.buildCommand(validatedTask);

    return shell.runCommand(command, log);
  }
}

/**
  Performs basic validation on a task:
  1. `command` property exists and is a string.
  2. `options` property is an object.

  @method validateTasks
  @param {Object} task
**/
function validateTask(task) {
  if (typeof task.command !== 'string') {
    return;
  }

  if (task.options === null) {
    return;
  }

  if (task.options && typeof task.options !== 'object') {
    return;
  }

  return task;
}
